﻿// Copyright (c) 2020 Tudor Stanciu

using System.Linq;
using Tuitio.Application.Extensions;
using Tuitio.Application.Services.Abstractions;
using Tuitio.Domain.Abstractions;
using Tuitio.Domain.Entities;
using Tuitio.Domain.Models;

namespace Tuitio.Application.Services
{
    internal class TokenService : ITokenService
    {
        private readonly IConfigProvider _configProvider;

        public TokenService(IConfigProvider configProvider)
        {
            _configProvider=configProvider;
        }

        public TokenExtension GenerateToken(AppUser user)
        {
            var claims = user.Claims?.ToDictionary();
            var userRoles = user.GetUserRoles().AsRecordIdentifiers();
            var userGroups = user.UserGroups?.Select(z => z.UserGroup).AsRecordIdentifiers();
            var token = Token.Initialize(_configProvider.Token.ValidityInMinutes, user.UserId, user.UserName, user.FirstName, user.LastName, user.Email, user.SecurityStamp, claims);
            var extension = token.Extend(userRoles, userGroups);
            return extension;
        }
    }
}
